==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-appintegrations/source/model/ListDataIntegrationAssociationsResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/appintegrations/model/ListDataIntegrationAssociationsResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::AppIntegrationsService::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListDataIntegrationAssociationsResult::ListDataIntegrationAssociationsResult()
{
}

ListDataIntegrationAssociationsResult::ListDataIntegrationAssociationsResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListDataIntegrationAssociationsResult& ListDataIntegrationAssociationsResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("DataIntegrationAssociations"))
  {
    Array<JsonView> dataIntegrationAssociationsJsonList = jsonValue.GetArray("DataIntegrationAssociations");
    for(unsigned dataIntegrationAssociationsIndex = 0; dataIntegrationAssociationsIndex < dataIntegrationAssociationsJsonList.GetLength(); ++dataIntegrationAssociationsIndex)
    {
      m_dataIntegrationAssociations.push_back(dataIntegrationAssociationsJsonList[dataIntegrationAssociationsIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("NextToken"))
  {
    m_nextToken = jsonValue.GetString("NextToken");

  }



  return *this;
}

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-appintegrations/source/model/ListDataIntegrationAssociationsResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/appintegrations/model/ListDataIntegrationAssociationsResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::AppIntegrationsService::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListDataIntegrationAssociationsResult::ListDataIntegrationAssociationsResult()
{
}

ListDataIntegrationAssociationsResult::ListDataIntegrationAssociationsResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListDataIntegrationAssociationsResult& ListDataIntegrationAssociationsResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("DataIntegrationAssociations"))
  {
    Aws::Utils::Array<JsonView> dataIntegrationAssociationsJsonList = jsonValue.GetArray("DataIntegrationAssociations");
    for(unsigned dataIntegrationAssociationsIndex = 0; dataIntegrationAssociationsIndex < dataIntegrationAssociationsJsonList.GetLength(); ++dataIntegrationAssociationsIndex)
    {
      m_dataIntegrationAssociations.push_back(dataIntegrationAssociationsJsonList[dataIntegrationAssociationsIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("NextToken"))
  {
    m_nextToken = jsonValue.GetString("NextToken");

  }



  return *this;
}
